( cd usr/lib ; rm -rf libpstoedit.so.0 )
( cd usr/lib ; ln -sf libpstoedit.so.0.0.0 libpstoedit.so.0 )
( cd usr/lib ; rm -rf libpstoedit.so )
( cd usr/lib ; ln -sf libpstoedit.so.0.0.0 libpstoedit.so )
( cd usr/lib/pstoedit ; rm -rf libp2edrvstd.so.0 )
( cd usr/lib/pstoedit ; ln -sf libp2edrvstd.so.0.0.0 libp2edrvstd.so.0 )
( cd usr/lib/pstoedit ; rm -rf libp2edrvstd.so )
( cd usr/lib/pstoedit ; ln -sf libp2edrvstd.so.0.0.0 libp2edrvstd.so )
( cd usr/lib/pstoedit ; rm -rf libp2edrvmagick++.so.0 )
( cd usr/lib/pstoedit ; ln -sf libp2edrvmagick++.so.0.0.0 libp2edrvmagick++.so.0 )
( cd usr/lib/pstoedit ; rm -rf libp2edrvmagick++.so )
( cd usr/lib/pstoedit ; ln -sf libp2edrvmagick++.so.0.0.0 libp2edrvmagick++.so )
